; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
; The CMD file.

;-| AI/CPU Commands |-----------

[Command]
name = "cpu_1"
command = U, U, U, U, U, U, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_2"
command = D, D, D, D, D, D, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_3"
command = B, B, B, B, B, B, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_4"
command = F, F, F, F, F, F, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_5"
command = a, a, a, a, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_6"
command = b, b, b, b, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_7"
command = c, c, c, c, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_8"
command = x, x, x, x, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_9"
command = y, y, y, y, y, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_10"
command = z, z, z, z, z, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_11"
command = U, U, U, U, U, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_12"
command = D, D, D, D, D, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_13"
command = B, B, B, B, B, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_14"
command = F, F, F, F, F, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_15"
command = U, U, U, U, U, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_16"
command = D, D, D, D, D, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_17"
command = B, B, B, B, B, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_18"
command = F, F, F, F, F, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_19"
command = U, U, U, U, U, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_20"
command = D, D, D, D, D, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_21"
command = B, B, B, B, B, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_22"
command = F, F, F, F, F, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_23"
command = U, U, U, U, U, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_24"
command = D, D, D, D, D, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_25"
command = B, B, B, B, B, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_26"
command = F, F, F, F, F, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_27"
command = U, U, U, U, U, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_28"
command = D, D, D, D, D, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_29"
command = B, B, B, B, B, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_30"
command = F, F, F, F, F, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_31"
command = U, U, U, U, U, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_32"
command = D, D, D, D, D, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_33"
command = B, B, B, B, B, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_34"
command = F, F, F, F, F, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_35"
command = U, U, U, U, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_36"
command = D, D, D, D, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_37"
command = B, B, B, B, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_38"
command = F, F, F, F, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_39"
command = U, U, U, U, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_40"
command = D, D, D, D, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_41"
command = B, B, B, B, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_42"
command = F, F, F, F, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_43"
command = U, U, U, U, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_44"
command = D, D, D, D, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_45"
command = B, B, B, B, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_46"
command = F, F, F, F, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_47"
command = U, U, U, U, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_48"
command = D, D, D, D, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_49"
command = B, B, B, B, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_17"
command = B, B, B, B, B, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_18"
command = F, F, F, F, F, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_19"
command = U, U, U, U, U, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_20"
command = D, D, D, D, D, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_21"
command = B, B, B, B, B, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_22"
command = F, F, F, F, F, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_23"
command = U, U, U, U, U, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_24"
command = D, D, D, D, D, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_25"
command = B, B, B, B, B, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_26"
command = F, F, F, F, F, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_27"
command = U, U, U, U, U, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_28"
command = D, D, D, D, D, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_29"
command = B, B, B, B, B, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_30"
command = F, F, F, F, F, y, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_31"
command = U, U, U, U, U, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_32"
command = D, D, D, D, D, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_33"
command = B, B, B, B, B, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_34"
command = F, F, F, F, F, z, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_35"
command = U, U, U, U, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_36"
command = D, D, D, D, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_37"
command = B, B, B, B, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_38"
command = F, F, F, F, a, a, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_39"
command = U, U, U, U, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_40"
command = D, D, D, D, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_41"
command = B, B, B, B, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_42"
command = F, F, F, F, b, b, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_43"
command = U, U, U, U, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_44"
command = D, D, D, D, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_45"
command = B, B, B, B, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_46"
command = F, F, F, F, c, c, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_47"
command = U, U, U, U, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_48"
command = D, D, D, D, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_49"
command = B, B, B, B, x, x, U, U, U, U, U, U
time = 2
[Command]
name = "cpu_50"
command = F, F, F, F, x, x, U, U, U, U, U, U
time = 2


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
Name= "super_golpe_a"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
Name= "super_golpe_b"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
Name= "super_golpe_c"
command = ~D, DF, F, D, DF, F, c
time = 23

[Command]
Name= "super_misil_x"
command = ~D,D,D,B,F, x+y
time = 35

[Command]
Name= "super_misil_y"
command = ~D, DF, F, D, DF, F,D, DF, F, y+x
time = 25
[Command]
Name= "super_misil_y"
command = ~D, D,D,U
time = 25


[Command]
Name= "super_misil_z"
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
Name= "muertocad"
command = ~a,z,z,b 
time = 35

[Command]
Name= "aroseforthedead"
command = ~D,D,D,F,s 
time = 30

[Command]
Name= "pblackdp"
command = ~a,c,a,b,a 
time = 40

[Command]
Name= "demonhelpstwo"
command = x+b 
time = 10

;-| Special Motions |------------------------------------------------------
[Command]
Name= "misil_x"
command = ~D, DF, F, x

[Command]
Name= "misil_y"
command = ~D, DF, F, y

[Command]
Name= "misil_z"
command = ~D, DF, F, z

[Command]
Name = "ge01"
command = ~D, B, y

[Command]
name = "tki_a"
command = ~D, F, a

[Command]
name = "gaup_y"
command = ~F, D, DF, y

[Command]
name = "pisoh"
command = ~30z
time = 25

[Command]
name = "z+c"
command = z+c

[Command]
name = "rpat"
command = ~D, F, c

[Command]
name = "circu"
command = ~D, D, z

[Command]
name = "circu"
command = ~D, D, x

[Command]
name = "circu"
command = ~D, D, y

[Command]
name = "kinetic"
command = ~B, D,B, z

[Command]
name = "kinex"
command = ~B,F, x

[Command]
name = "kiney"
command = ~B,F, y

[Command]
name = "kinez"
command = ~B,F, z

[Command]
Name= "lostsoul_z"
command = ~F,B, z

[Command]
name = "girogsu"
command = ~D,D, c

[Command]
name = "girogsu"
command = ~D,D, b

[Command]
name = "fumon"
command = ~F,B, y

[Command]
name = "fumon"
command = ~F,B, x


[Command]
Name= "airmisil_y"
command = ~D, DF, F, y

[Command]
Name= "a+xdel"
command = /F, a+x
time = 15
[Command]
Name= "a+xtras"
command = /B, a+x
time = 15
[Command]
Name= "a+xes"
command = a+x+y


[Command]
Name= "tt0"
command = ~D,DF,F,B, x
[Command]
Name= "tt1"
command = ~D,DF,F,B, y
[Command]
Name= "tt2"
command = ~D,DF,F,B, c
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Artificial Inteligence
;---------------------------------------------------------------------------

[State -1]
type = VarSet
trigger1  = command = "cpu_1"
trigger2  = command = "cpu_2"
trigger3  = command = "cpu_3"
trigger4  = command = "cpu_4"
trigger5  = command = "cpu_5"
trigger6  = command = "cpu_6"
trigger7  = command = "cpu_7"
trigger8  = command = "cpu_8"
trigger9  = command = "cpu_9"
trigger10 = command = "cpu_10"
trigger11 = command = "cpu_11"
trigger12 = command = "cpu_12"
trigger13 = command = "cpu_13"
trigger14 = command = "cpu_14"
trigger15 = command = "cpu_15"
trigger16 = command = "cpu_16"
trigger17 = command = "cpu_17"
trigger18 = command = "cpu_18"
trigger19 = command = "cpu_19"
trigger20 = command = "cpu_20"
trigger21 = command = "cpu_21"
trigger22 = command = "cpu_22"
trigger23 = command = "cpu_23"
trigger24 = command = "cpu_24"
trigger25 = command = "cpu_25"
trigger26 = command = "cpu_26"
trigger27 = command = "cpu_27"
trigger28 = command = "cpu_28"
trigger29 = command = "cpu_29"
trigger30 = command = "cpu_30"
trigger31 = command = "cpu_31"
trigger32 = command = "cpu_32"
trigger33 = command = "cpu_33"
trigger34 = command = "cpu_34"
trigger35 = command = "cpu_35"
trigger36 = command = "cpu_36"
trigger37 = command = "cpu_37"
trigger38 = command = "cpu_38"
trigger39 = command = "cpu_39"
trigger40 = command = "cpu_40"
trigger41 = command = "cpu_41"
trigger42 = command = "cpu_42"
trigger43 = command = "cpu_43"
trigger44 = command = "cpu_44"
trigger45 = command = "cpu_45"
trigger46 = command = "cpu_46"
trigger47 = command = "cpu_47"
trigger48 = command = "cpu_48"
trigger49 = command = "cpu_49"
trigger50 = command = "cpu_50"
v = 59
value = 1

;---------------------------------------------------------------------------
; super misiles
[State -1]
type = ChangeState
value = 7049
triggerall=command="super_misil_x"
triggerall = power >= 3000 ;Level 1
triggerall = life <=  200
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;-------------------------------------
[State -1]
type = ChangeState
value = 7060
triggerall=command="super_misil_y"
;triggerall = power >= 1000 ;Level 1
triggerall = p2life <=  150
trigger1 = (statetype = S) && (EnemyNear,statetype != A) && (EnemyNear,statetype!=L)
trigger1 = (stateno != 100) && (p2bodydist X <= 25)
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1

[State -1]
type = ChangeState
value = 3000
triggerall=command="super_misil_z"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1


;===========================================================================
; super golpes
[State -1]
type = ChangeState
value = 7000
triggerall=command="super_golpe_a"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact = 1
[State -1]
type = ChangeState
value = 7003
triggerall=command="super_golpe_b"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact = 1

[State -1]
type = ChangeState
value = 7010
triggerall=command="super_golpe_c"
triggerall = power >= 2000 ;Level 1
trigger1 = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
;trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1

;---------------------
[State -1]
type = ChangeState
value = 7200
triggerall=command="aroseforthedead"
triggerall = power >= 1000 
;trigger1 = life <=  350
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;---------------------
[State -1]
type = ChangeState
value = 7350
triggerall=command="muertocad"
triggerall = power >= 1000 
triggerall = p2life <=  200
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
;trigger2 = movecontact = 1
;---------------------
;
[State -1]
type = ChangeState
value = 7410
triggerall=command="pblackdp"
triggerall = power >= 3000 
;trigger1 = life <=  350
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;---------------------
[State -1]
type = ChangeState
value = 7260
triggerall=command="demonhelpstwo"
triggerall = power >= 1000 
;trigger1 = life <=  350
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1

;----------------------------------------------
;===========================================================================
;---------------------------------------------------------------------------
;esquiva 
[State -1]
type = ChangeState
value = 6022
triggerall=command="a+xes"
;triggerall=command ="holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230
;esquiva atras
[State -1]
type = ChangeState
value = 6021
triggerall=command="a+xtras"
;triggerall=command ="holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230

;esquiva adelante
[State -1]
type = ChangeState
value = 6020
triggerall=command="a+xdel"
;triggerall=command ="holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230

[State -1, Teleport Throwst]
type = Changestate
value = 6014
triggerAll = command = "tt0"
;triggerall = P2statetype != A
;triggerall = P2statetype != L
trigger1 = ctrl = 1
trigger1 = statetype = S
[State -1, Teleport Throwst1]
type = Changestate
value = 6015
triggerAll = command = "tt1"
;triggerall = P2statetype != A
;triggerall = P2statetype != L
trigger1 = ctrl = 1
trigger1 = statetype = S
[State -1, Teleport Throwst1]
type = Changestate
value = 6016
triggerAll = command = "tt2"
;triggerall = P2statetype != A
;triggerall = P2statetype != L
trigger1 = ctrl = 1
trigger1 = statetype = S


;Flykick_A
[State -1]
type = ChangeState
value = 6002
triggerall = command = "tki_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = command = "tatsumaki_a"
;trigger2 = statetype = C
trigger1 = statetype != A
trigger2 = ctrl = 1
trigger2 = stateno = [200, 450]
;trigger2 = movecontact = 1

; piso humeante
[State -1]
type = ChangeState
value = 6006
triggerall = command = "pisoh"
trigger1 = statetype = S
trigger1 = ctrl = 1

;rpatada
[State -1,rpat]
type = ChangeState
value = 6010
triggerall = command = "rpat"
trigger1 = statetype != A
trigger1 = ctrl 
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
;trigger2 = (stateno = [200,299]) || (stateno = [400,499])
;trigger2 = stateno != 440 ;Except for sweep kick
;trigger2 = stateno = [200, 450]
trigger2 = movecontact
;---------------------------------------------------------------------------
;phumo circular
;p
[State -1, p]
type = ChangeState
value = 6011
triggerall = command = "circu"
;triggerall = power >= 330
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------

[State -1, girog]
type = ChangeState
value = 6810
triggerall = command = "girogsu"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;fumon
[State -1, fumon]
type = ChangeState
value = 6812
triggerall = command = "fumon"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
;trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;---------------------
[State -1]
type = ChangeState
value = 6700
triggerall=command="kinex"
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;---------------------
[State -1]
type = ChangeState
value = 6710
triggerall=command="kiney"
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;---------------------
[State -1]
type = ChangeState
value = 6715
triggerall=command="kinez"
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;-----------------------------------------------
[State -1]
type = ChangeState
value = 6750
triggerall=command="lostsoul_z"
triggerall = power >= 250
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;kinetic
[State -1]
type = ChangeState
value = 6012
triggerall = command = "kinetic";-------
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])

;---------------------------------------------------------------------------
;upperarriba_y
[State -1]
type = ChangeState
value = 6008
triggerall = command = "gaup_y";-------
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = [200, 450]

;---------------------------------------------------------------------------
;Uppercut
[State -1]
type = ChangeState
value = 6007
triggerall = command = "z+c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;----------------------------------------------------------------------
;------------------------
;ge01
;Jt[˂ij
[State -1,ge01]
type = ChangeState
value = 6001
triggerall = command = "ge01"
trigger1 = statetype != A
trigger1 = ctrl 
;trigger2 = (stateno = [200,299]) || (stateno = [400,499])
;trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = stateno = [200, 450]
trigger2 = movecontact
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 6013
triggerall=command="airmisil_y"
triggerall = numproj = 0
;trigger1 = statetype != S
;trigger1 = statetype != C
;trigger1 = ctrl = 1
;trigger2 = stateno = [200, 450]
;trigger1 = movecontact = 1
trigger1 = statetype = A && ctrl 
 

; misiles
[State -1]
type = ChangeState
value = 1000
triggerall=command="misil_x"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1

[State -1]
type = ChangeState
value = 1020
triggerall=command="misil_y"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
;trigger2 = stateno = [220, 450]
trigger2 = movecontact 

[State -1]
type = ChangeState
value = 1020
triggerall=command="misil_z"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = [200, 450]
trigger2 = movecontact = 1
;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------

;Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
;trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
;trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H




;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
;[State -1, Stand Strong Punch]
;type = ChangeState
;value = 210
;triggerall = command = "y"
;triggerall = command != "holddown"
;trigger1 = statetype = S
;trigger1 = ctrl
;trigger2 = (stateno = 200) && time > 5
;trigger3 = (stateno = 230) && time > 6
;trigger2 = stateno = 210
;--------------------------------------------------------
;Stand_y
[State -1]
type = ChangeState
value = 210
triggerall=command="y"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 220) && time > 5
;trigger2 = movecontact = 1
;------------------------------------------------------------
;Stand_z
[State -1]
type = ChangeState
value = 220
triggerall=command="z"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = movecontact = 1
;-----------------------------------------------------------------------------


;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
;trigger3 = (stateno = 230) && time > 6
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;----------------------------------------------------------------------
;Stand_c
[State -1]
type = ChangeState
value = 250
triggerall=command="c"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger3 = movecontact = 1
;-----------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)
;-----------------------------------------------------------------------
;Crouch_z
[State -1]
type = ChangeState
value = 420
triggerall=command="z"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)
;---------------------------------------------------------------------------
;Crouch_c
[State -1]
type = ChangeState
value = 450
triggerall=command="c"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
;---------------------------------------------------------------------------
;Jump_z
[State -1]
type = ChangeState
value = 620
trigger1=command="z"
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl



;Jump_c
[State -1]
type = ChangeState
value = 650
trigger1=command="c"
trigger1 = statetype = A
trigger1 = ctrl = 1



;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
;===========================================================================
;---------------------------------------------------------------------------
;Artificial Inteligence
;---------------------------------------------------------------------------
[State -1, conthumomisil]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = ctrl && random <= 222 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 6006
[State -1, port1ai]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = P2BodyDist X <= 75
trigger1 = ctrl && random <= 555 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 6015
[State -1, conthumomisil]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = P2BodyDist X <= 25
trigger1 = ctrl && random <= 555 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 6016
[State -1,humeante at]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X >=100 && Random <= 999
trigger1 = P2StateType = S
trigger1 = P2StateType = C
trigger1 = P2StateType != A
Trigger1 = Statetype = S
;trigger1 = Ctrl && P2MoveType = A && StateType = C
value = 6006
[State -1,humeante at2]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = Random <= 999
trigger1 = P2StateType = S
trigger1 = P2StateType = C
trigger1 = P2StateType != A
Trigger1 = Statetype = S
;trigger1 = Ctrl && P2MoveType = A && StateType = C
value = 6006

;lkick ai
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X >=95 && Random <= 999
trigger1 = P2StateType = S
Trigger1 = Statetype = C
;trigger1 = Ctrl && P2MoveType = A && StateType = C
value = 6002
[State -1, contmisil]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = ctrl && random <= 666 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 6020
[State -1, 1]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = ctrl && random <= 666 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 6016

;lai kinez
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X >=250 && Random <= 777
trigger1 = P2StateType = S
;Trigger1 = Statetype = C
trigger1 = Ctrl && P2MoveType = A && StateType = C
value = 6715

[State -1, 1]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = ctrl && random <= 999 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 6020

[State -1, poder01]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = power >= 1000
trigger1 = ctrl && random <= 999 && statetype = S
trigger1 = enemy, NumProj >= 1
value = 7003

;pouder01
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = power >= 1000
trigger1 = life <=  400
trigger1 = P2BodyDist Y <= 75 && Random <= 555
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 7003

;poder02
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = power >= 2000
trigger1 = life <=  500
trigger1 = P2BodyDist Y <= 75 && Random <= 666
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 7010

;pouder03
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = power >= 3000
trigger1 = life <=  200
trigger1 = P2BodyDist Y <= 75 && Random <= 555
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 7049

;pouder03poder
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = power >= 3000
trigger1 = life <=  500
trigger1 = P2BodyDist Y <= 75 && Random <= 999
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 7410

;pouder03poderproy
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = power >= 3000
trigger1 = life <=  500
trigger1 = P2BodyDist X <= 75 && Random <= 999
trigger1 = Ctrl && P2MoveType = A && StateType = S
trigger1 = enemy, NumProj >= 1
value = 7410

[State -1, poder01rosa]
type = ChangeState
trigger1 = roundstate = 2 && var(59) != 0 
trigger1 = power >= 1000
trigger1 = ctrl && random <= 444 && statetype = S
trigger1 = P2BodyDist X >=75 && Random <= 666
trigger1 = P2StateType = S
;trigger1 = enemy, NumProj >= 1
value = 7200

;pofatalesque
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = p2life <=  200
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger1 = P2BodyDist x <= 85 && Random <= 999
trigger1 = Ctrl && P2MoveType = A && StateType = S
trigger1 = power >= 1000
trigger1 = P2StateType = S
value = 7350

;giro
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X <= 45 && Random <= 888
trigger1 = Ctrl && P2MoveType = A && StateType = S
trigger1 = P2StateType = S
value = 6810



;fumon01
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X <= 35 && Random <= 222
trigger1 = Ctrl && P2MoveType = A && StateType = S
trigger1 = P2StateType = S
trigger1 = statetype != A
value = 6812

;pofatal
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = p2life <=  150
trigger1 = (statetype = S) && (EnemyNear,statetype != A) && (EnemyNear,statetype!=L)
trigger1 = (stateno != 100) && (p2bodydist X <= 25)
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger1 = P2BodyDist Y <= 25 && Random <= 999
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 7060



;[State -1, 1]
;type = ChangeState
;trigger1 = roundstate = 2 && var(59) != 0 
;trigger1 = ctrl && random <= 999 && statetype = S
;trigger1 = enemy, NumProj >= 1
;value = 40
;[State -1, 2]
;type = ChangeState
;trigger1 = roundstate = 2 && var(59) != 0 && Stateno = 40
;trigger1 = ctrl && random <= 999 && statetype = S
;trigger1 = enemy, NumProj >= 1
;value = 41

;nicotin at00
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist Y <= 75 && Random <= 666
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 6011


;Stand Guard
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X <= 75 && Random <= 999
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 130

;Stand Guard ataqueaire
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist Y <= 75 && Random <= 999
trigger1 = Ctrl && P2MoveType = A && StateType = S
value = 130

;Stand Guard crouch
[State -1]
type = ChangeState
trigger1 = RoundState = 2 && Var(59) != 0
trigger1 = P2BodyDist X <= 75 && Random <= 999
trigger1 = P2StateType = C
Trigger1 = Statetype = C
trigger1 = Ctrl && P2MoveType = A && StateType = C
value = 131

[State -1, CrouchGuard]
type = ChangeState
triggerall = (Var(59) = 1) && (StateType != A) && (Pos Y >= 0) && (P2BodyDist Y <= 0)
triggerall = (P2BodyDist Y >= -50) && (P2StateType = C) && (P2MoveType = A)&& Random <= 999
trigger1 = (P2BodyDist X <= 120) && (Random <= 799) && (Ctrl)
trigger2 = (StateNo = [140, 155]) || (StateNo = [100, 105])
value = 131

[State -1, AirGuard]
type = ChangeState
triggerall = (Var(59) = 1) && (StateType = A) && (Pos Y < 0) && (P2BodyDist Y >= -120) && Random <= 999
triggerall = (StateType = A) && (P2MoveType = A)
trigger1 = ((P2BodyDist X <= 120) && (Ctrl)) || (StateNo = [140, 155])
value = 132


---------------------

